@@ -39,9 +39,9 @@
 
 // Reserve 2 digits for patch number, 2 digits for the minor number and the rest
 // for the major.
-#define ALEMBIC_LIBRARY_VERSION 1 * 10000 + 7 * 100 + 10
+#define ALEMBIC_LIBRARY_VERSION 1 * 10000 + 7 * 100 + 13
 
-/* #undef ALEMBIC_WITH_HDF5 */
+#define ALEMBIC_WITH_HDF5
 
 /* #undef ALEMBIC_LIB_USES_BOOST */
 
